package
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: Jan 14, 2026
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type EdgeJSON struct {
From string `json:"from"`
To string `json:"to"`
}
type GraphJSON struct {
Nodes []NodeJSON `json:"nodes"`
Edges []EdgeJSON `json:"edges"`
}
type NodeJSON struct {
ID string `json:"id"`
Bundle string `json:"bundle"`
Name string `json:"name"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.